#!/usr/bin/python.exe
if __name__ == '__main__':
  import sys
  import os
  sys.path.insert(0, os.path.abspath('config'))
  import configure
  configure_options = [
    '--PETSC_ARCH=sto',
    '--with-cxx=0',
    '--with-debugging=0',
    '--with-fc=0',
    '--with-hwloc=1',
    '--with-mpi=0',
    '--with-openblas-dir=/clangarm64',
    '--with-openblas=1',
    '--with-openmp=1',
    '--with-precision=single',
    '--with-pthread=0',
    '--with-scalar-type=real',
    '--with-shared-libraries=0',
    '--with-single-library=1',
    '--with-windows-graphics=0',
    '--with-x=0',
    'CC=clang',
    'CFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-incompatible-function-pointer-types',
    'CPPFLAGS=',
    'CXX=clang++',
    'CXXFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1',
    'FC=',
    'FFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -I/clangarm64/include',
    'LDFLAGS= -fopenmp',
    'LIBS=',
    'MAKEFLAGS=-j3',
  ]
  configure.petsc_configure(configure_options)
